==> vtigercrm-5.2.1.tgz: modules/com_vtiger_workflow/language/de_de.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved. German Version created by crm-now www.crm-now.com
 ************************************************************************************/
$mod_strings = array(
'VTEmailTask' => 'Sende E-Mail',
'VTEntityMethodTask' => 'benutzerdefinierte Funktion aktivieren',
'VTCreateTodoTask' => 'Aufgabe erzeugen',
'VTCreateEventTask' => 'Ereignis erzeugen',
'VTSMSTask' => 'SMS Aufgabe',
'LBL_EDIT_TASK'=>'Aufgabe bearbeiten',
'LBL_EDIT_TASK_TITLE'=>'bearbeite eine Aufgabe oder erzeuge eine neue',
'LBL_EDIT_WORKFLOW'=>'Workflow bearbeiten',
'LBL_EDIT_WORKFLOW_TITLE'=>'bearbeite Workflow oder erzeugen einen neuen',
'LBL_FROM_TEMPLATE'=>'aus einer Vorlage',
'LBL_NEW_WORKFLOW'=>'neuer Workflow',
'LBL_NEW_TEMPLATE'=>'als Vorlage speichern',
'LBL_CREATE_WORKFLOW_FOR'=>'Erzeuge Workflow für',
'LBL_FOR_MODULE'=>'für Modul',
'LBL_CHOOSE_A_TEMPLATE'=>'Vorlage auswählen',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'Pflichtfelder sind leer.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'Die Anfangszeit liegt nach der Endezeit',
'LBL_ERROR_NO_WORKFLOW'=>'Dieser Workflow existiert nicht',
'LBL_ERROR_NO_TASK'=>'Diese Aufgabe existiert nicht',
'LBL_ERROR_NOT_ADMIN'=>'Diesen CRM Modul können nur Nutzer mit Administratorrechten nutzen.',
'LBL_CREATE_WORKFLOW'=>'Workflow erzeugen',
'LBL_WORKFLOW_LIST'=>'Workflow Liste',
'LBL_AVAILABLE_WORKLIST_LIST'=>'verfügbare Workflows',
'LBL_LOADING'=>'Lade...',
'LBL_VALIDATION_ERROR'=>'Überprüfungsfehler',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Option auswählen...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'Hinweis: Sie können die Ersatzfelder verwenden',
'LBL_NO_TEMPLATES'=>'keine Vorlagen verfügbar',
'LBL_SELECT'=>'Wähle',
'LBL_MESSAGE'=>'Nachricht',
);


?>

==> vtigercrm-5.3.0p0.tgz: modules/com_vtiger_workflow/language/de_de.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 ************************************************************************************/
$mod_strings = array(
'VTEmailTask' => 'Sende E-Mail',
'VTEntityMethodTask' => 'benutzerdefinierte Funktion aktivieren',
'VTCreateTodoTask' => 'Aufgabe erzeugen',
'VTCreateEventTask' => 'Ereignis erzeugen',
'VTSMSTask' => 'SMS Aufgabe',
'LBL_EDIT_TASK'=>'Aufgabe bearbeiten',
'LBL_EDIT_TASK_TITLE'=>'bearbeite eine Aufgabe oder erzeuge eine neue',
'LBL_EDIT_WORKFLOW'=>'Workflow bearbeiten',
'LBL_EDIT_WORKFLOW_TITLE'=>'bearbeite Workflow oder erzeugen einen neuen',
'LBL_FROM_TEMPLATE'=>'aus einer Vorlage',
'LBL_NEW_WORKFLOW'=>'neuer Workflow',
'LBL_NEW_TEMPLATE'=>'als Vorlage speichern',
'LBL_CREATE_WORKFLOW_FOR'=>'Erzeuge Workflow für',
'LBL_FOR_MODULE'=>'für Modul',
'LBL_CHOOSE_A_TEMPLATE'=>'Vorlage auswählen',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'Pflichtfelder sind leer.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'Die Anfangszeit liegt nach der Endezeit',
'LBL_ERROR_NO_WORKFLOW'=>'Dieser Workflow existiert nicht',
'LBL_ERROR_NO_TASK'=>'Diese Aufgabe existiert nicht',
'LBL_ERROR_NOT_ADMIN'=>'Diesen CRM Modul können nur Nutzer mit Administratorrechten nutzen.',
'LBL_CREATE_WORKFLOW'=>'Workflow erzeugen',
'LBL_WORKFLOW_LIST'=>'Workflow Liste',
'LBL_AVAILABLE_WORKLIST_LIST'=>'verfügbare Workflows',
'LBL_LOADING'=>'Lade...',
'LBL_VALIDATION_ERROR'=>'Überprüfungsfehler',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Option auswählen...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'Hinweis: Sie können die Ersatzfelder verwenden',
'LBL_NO_TEMPLATES'=>'keine Vorlagen verfügbar',
'LBL_SELECT'=>'Wähle',
'LBL_MESSAGE'=>'Nachricht',

'LBL_SET_FIELD_VALUES'=>'Werte für das Feld setzen',
'LBL_ADD_FIELD'=>'Feld hinzufügen',

'LBL_USE_FIELD_VALUE_DASHDASH'=>'-- benutze Feldwert --',
'LBL_USE_FUNCTION_DASHDASH'=>'-- Funktion benutzen --',

'LBL_RAW_TEXT'=>'Rohtext',
'LBL_FIELD'=>'Feld',
'LBL_EXPRESSION'=>'Bedingung',
'LBL_SET_EXPRESSION'=>'Bedingung setzen',

'LBL_MANUAL'=>'System',

'LBL_NEW_CONDITION_GROUP_BUTTON_LABEL'=>'Neue Bedingungs-Gruppe',

'VTUpdateFieldsTask' => 'Felder aktualisieren',


'LBL_VALIDATION_DUPLICATE_FIELDNAMES' => 'Selbes Feld wurde mehrmals ausgewählt.',
'LBL_VALIDATION_INVALID_FIELD_VALUES' => 'Ungültiger Wert',
'LBL_CREATE_ENTITY_NOTE_ORDER_MATTERS' => 'Hinweis: Ausdrücke werden in der selben Reihenfolge geprüft, wie sie gesetzt werden.
										   Stellen Sie sicher, dass ein Wert für ein Feld gesetzt wird, bevor Sie es als Ausdruck verwenden.',
'LBL_SET_VALUE' => 'Wert setzen',

'LBL_EMAIL_RECIPIENT' => 'Empfänger',
'LBL_EMAIL_CC' => 'CC',
'LBL_EMAIL_BCC' => 'BCC',
'LBL_EMAIL_SUBJECT' => 'Betreff',

'LBL_WORKFLOW_NOTE_EVENT_TASK_TIMEZONE' => 'Hinweis: Alle Datums, Zeit und wiederkehrende Informationen, welche für das Ereignis konfiguriert wurden, 
											sind abhängig der gesetzten Zeitzone, welche in der config.inc.php festgelegt wurde.',
	
);


?>
